crystal_toolkit.renderables.structure module — Crystal Toolkit documentation

# crystal_toolkit.renderables.structure module

crystal_toolkit.renderables.structure.get_structure_scene(self, origin: list[float] = None, legend: Legend | None = None, draw_image_atoms: bool = True) → Scene

  Create CTK objects for the lattice and sties :param self: Structure object :param origin: fractional coordinate of the origin :param legend: Legend for the sites :param draw_image_atoms: If true draw image atoms that are just outside the :param periodic boundary:

  Returns

    CTK scene object to be rendered